"""Script for running tsunami inundation scenario for Dampier, WA, Australia.

Source data such as elevation and boundary data is assumed to be available in
directories specified by project.py
The output sww file is stored in project.output_run_time_dir 

The scenario is defined by a triangular mesh created from project.polygon,
the elevation data and a simulated tsunami generated with URS code.

Ole Nielsen and Duncan Gray, GA - 2005 and Jane Sexton, Nick Bartzis, GA - 2006
"""

#------------------------------------------------------------------------------
# Import necessary modules
#------------------------------------------------------------------------------

# Standard modules

# # Related major packages
# from anuga.shallow_water import Domain
from anuga.shallow_water.data_manager import URS_points_needed_to_file, \
     urs_ungridded2sww
#import project                 # Definition of file names and polygons

#-----------------------------------------------------------------------------
# With no project file
#-----------------------------------------------------------------------------
from anuga.utilities.polygon import read_polygon, plot_polygons, polygon_area, is_inside_polygon
from os import sep, environ, getenv, getcwd ,umask
from anuga.utilities.system_tools import get_user_name, get_host_name

# INUNDATIONHOME is the inundation directory, not the data directory.
home = getenv('INUNDATIONHOME') + sep +'data'+sep #Sandpit's parent dir   
user = get_user_name()
host = get_host_name()

#Making assumptions about the location of scenario data
state = 'western_australia'
scenario_name = 'carnarvon'
scenario = 'carnarvon_tsunami_scenario'

anuga_dir = home+state+sep+scenario+sep+'anuga'+sep
polygons_dir = anuga_dir+'polygons'+sep

#boundaries locations
boundaries_in_dir = anuga_dir + sep + 'boundaries' + sep + scenario_name
boundaries_dir = anuga_dir+'boundaries'+sep
boundaries_dir_name = boundaries_dir + scenario_name

# bounding polygon for study area
poly_all = read_polygon(polygons_dir+'poly_all.csv')



#-----------------------------------------------------------------------------
# run_boundary_points
#-----------------------------------------------------------------------------
  
LL_LAT = -50.0          #ll_lat - lower left latitude, in decimal degrees
LL_LONG = 80.0          #ll-long - lower left longitude, in decimal degrees
GRID_SPACING = 2.0/60.0 #grid_spacing - in deciamal degrees
LAT_AMOUNT = 4800       #lat_amount - number of latitudes 
LONG_AMOUNT = 3600      #long_amount- number of longs
ZONE = 49

#------------------------------------------------------------------------------
# Copy scripts to time stamped output directory and capture screen
# output to file
#------------------------------------------------------------------------------
poly = poly_all
print "poly", poly
print "project.boundaries_in_dir",boundaries_in_dir
URS_points_needed_to_file(boundaries_in_dir,poly, ZONE,
                          LL_LAT, LL_LONG,GRID_SPACING,LAT_AMOUNT, LONG_AMOUNT,export_csv=True)
#URS_points_needed_to_file(project.boundaries_dir_name5,poly, export_csv=True, zone=50)
#URS_points_needed_to_file(project.boundaries_dir_name5,poly, export_csv=True)
#urs_ungridded2sww(project.boundaries_in_dir_name2, project.boundaries_dir_name5, mean_stage= project.tide,  verbose=True)
